@@ -8,14 +8,12 @@
            (javax.net.ssl SSLSession SSLSocket)
            (org.apache.http.conn ClientConnectionManager)
            (org.apache.http.conn.params ConnPerRouteBean)
-           (org.apache.http.conn.ssl AllowAllHostnameVerifier SSLSocketFactory
-                                     TrustStrategy X509HostnameVerifier
-                                     SSLContexts)
+           (org.apache.http.conn.ssl SSLSocketFactory TrustStrategy
+                                     X509HostnameVerifier SSLContexts)
            (org.apache.http.conn.scheme PlainSocketFactory
                                         SchemeRegistry Scheme)
            (org.apache.http.impl.conn BasicClientConnectionManager
                                       PoolingClientConnectionManager
-                                      ProxySelectorRoutePlanner
                                       SchemeRegistryFactory
                                       SingleClientConnManager)))
 
@@ -45,6 +43,10 @@
                        (^boolean verify [_ ^String _ ^SSLSession _]
                          true))))
 
+(def ^SSLSocketFactory secure-ssl-socket-factory
+  (doto (SSLSocketFactory/getSocketFactory)
+    (.setHostnameVerifier SSLSocketFactory/STRICT_HOSTNAME_VERIFIER)))
+
 ;; New Generic Socket Factories that can support socks proxy
 (defn ^SSLSocketFactory SSLGenericSocketFactory
   "Given a function that returns a new socket, create an SSLSocketFactory that
@@ -89,9 +91,10 @@
 (def regular-scheme-registry
   (doto (SchemeRegistry.)
     (.register (Scheme. "http" 80 (PlainSocketFactory/getSocketFactory)))
-    (.register (Scheme. "https" 443 (SSLSocketFactory/getSocketFactory)))))
+    (.register (Scheme. "https" 443 secure-ssl-socket-factory))))
 
-(defn ^KeyStore get-keystore [keystore-file keystore-type ^String keystore-pass]
+(defn ^KeyStore get-keystore*
+  [keystore-file keystore-type ^String keystore-pass]
   (when keystore-file
     (let [keystore (KeyStore/getInstance (or keystore-type
                                              (KeyStore/getDefaultType)))]
@@ -99,8 +102,13 @@
         (.load keystore is (when keystore-pass (.toCharArray keystore-pass)))
         keystore))))
 
+(defn ^KeyStore get-keystore [keystore & args]
+  (if (instance? KeyStore keystore)
+    keystore
+    (apply get-keystore* keystore args)))
+
 (defn ^SchemeRegistry get-keystore-scheme-registry
-  [{:keys [keystore keystore-type keystore-pass
+  [{:keys [keystore keystore-type keystore-pass keystore-instance
            trust-store trust-store-type trust-store-pass]
     :as req}]
   (let [ks (get-keystore keystore keystore-type keystore-pass)
@@ -120,7 +128,7 @@
 
    (opt req :insecure) (BasicClientConnectionManager. insecure-scheme-registry)
 
-   :else (BasicClientConnectionManager.)))
+   :else (BasicClientConnectionManager. regular-scheme-registry)))
 
 ;; need the fully qualified class name because this fn is later used in a
 ;; macro from a different ns
