@@ -9,7 +9,7 @@
   (:require [puppetlabs.i18n.core :as i18n]
             [clojure.tools.logging :as log]
             [puppetlabs.kitchensink.core :as kitchensink]
-            [puppetlabs.trapperkeeper.bootstrap :refer [find-bootstrap-config]]
+            [puppetlabs.trapperkeeper.bootstrap :as tk-bootstrap]
             [clj-time.core :as time]
             [clojure.java.io :as io]
             [me.raynes.fs :as fs]
@@ -142,22 +142,28 @@
 (def command-processing-in
   "Schema for incoming command processing config (user defined) - currently incomplete"
   (all-optional
-    {:dlo-compression-threshold (pls/defaulted-maybe String "1d")
-     :threads (pls/defaulted-maybe s/Int half-the-cores)
-     :store-usage s/Int
-     :max-frame-size (pls/defaulted-maybe s/Int 209715200)
-     :temp-usage s/Int
-     :memory-usage s/Int
+    {:threads (pls/defaulted-maybe s/Int half-the-cores)
      :max-command-size (pls/defaulted-maybe s/Int (default-max-command-size))
-     :reject-large-commands (pls/defaulted-maybe String "false")}))
+     :reject-large-commands (pls/defaulted-maybe String "false")
+     :concurrent-writes (pls/defaulted-maybe s/Int (min half-the-cores 4))
+
+     ;; Deprecated
+     :dlo-compression-threshold (pls/defaulted-maybe String "1d")
+     :max-frame-size (pls/defaulted-maybe s/Int 209715200)
+     :store-usage s/Int
+     :temp-usage s/Int
+     :memory-usage s/Int}))
 
 (def command-processing-out
   "Schema for parsed/processed command processing config - currently incomplete"
-  {:dlo-compression-threshold Period
-   :threads s/Int
-   :max-frame-size s/Int
+  {:threads s/Int
    :max-command-size s/Int
    :reject-large-commands Boolean
+   :concurrent-writes s/Int
+
+   ;; Deprecated
+   :dlo-compression-threshold Period
+   :max-frame-size s/Int
    (s/optional-key :memory-usage) s/Int
    (s/optional-key :store-usage) s/Int
    (s/optional-key :temp-usage) s/Int})
@@ -166,8 +172,7 @@
   "Schema for validating the incoming [puppetdb] block"
   (all-optional
     {:certificate-whitelist s/Str
-     ;; The `historical-catalogs-limit` setting is only used by `pe-puppetdb`
-     :historical-catalogs-limit (pls/defaulted-maybe s/Int 3)
+     :historical-catalogs-limit (pls/defaulted-maybe s/Int 0)
      :disable-update-checking (pls/defaulted-maybe String "false")}))
 
 (def puppetdb-config-out
@@ -178,10 +183,12 @@
 
 (def developer-config-in
   (all-optional
-    {:pretty-print (pls/defaulted-maybe String "false")}))
+   {:pretty-print (pls/defaulted-maybe String "false")
+    :max-enqueued (pls/defaulted-maybe s/Int 1000000)}))
 
 (def developer-config-out
-  {:pretty-print Boolean})
+  {:pretty-print Boolean
+   :max-enqueued s/Int})
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Database config
@@ -237,8 +244,23 @@
   [{:keys [developer] :as config :or {developer {}}}]
   (configure-section config :developer developer-config-in developer-config-out))
 
+(def retired-cmd-proc-keys
+  [:dlo-compression-threshold :store-usage :max-frame-size :temp-usage :memory-usage])
+
+(defn warn-command-processing-retirements
+  [config]
+  (doseq [cmd-proc-key retired-cmd-proc-keys]
+    (when (get-in config [:command-processing cmd-proc-key])
+      (utils/println-err (format
+                          (str "The configuration item `%s`"
+                               " in the [command-processing] section is retired,"
+                               " please remove this item from your config."
+                               " Consult the documentation for more details.")
+                          (name cmd-proc-key))))))
+
 (defn configure-command-processing
   [config]
+  (warn-command-processing-retirements config)
   (configure-section config :command-processing command-processing-in command-processing-out))
 
 (defn convert-config
@@ -349,12 +371,15 @@
    {:route "/"
     :server "default"}})
 
+(defn filter-out-non-tk-config [config-data]
+  (select-keys config-data
+               [:debug :bootstrap-config :config :plugins :help]))
+
 (defn add-web-routing-service-config
   [config-data]
-  (let [bootstrap-cfg (-> (find-bootstrap-config config-data)
-                          slurp
-                          str/split-lines
-                          set)
+  (let [bootstrap-cfg (->> (tk-bootstrap/find-bootstrap-configs (filter-out-non-tk-config config-data))
+                           (mapcat tk-bootstrap/read-config)
+                           set)
         ;; If a user didn't specify one of the services in their bootstrap.cfg
         ;; we remove the web-router-config for that service
         filtered-web-router-config (into {} (for [[svc route] default-web-router-config
@@ -437,11 +462,8 @@
   [config]
   (get-in config [:command-processing :max-command-size]))
 
-(defn mq-dir [config]
-  (str (io/file (get-in config [:global :vardir]) "mq")))
-
-(defn mq-discard-dir [config]
-  (str (io/file (mq-dir config) "discard")))
+(defn stockpile-dir [config]
+  (str (io/file (get-in config [:global :vardir]) "stockpile")))
 
 (defprotocol DefaultedConfig
   (get-config [this]))
